Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org')
-rw-r--r--plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/RepresentationPackage.java4
-rw-r--r--plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/impl/RepresentationPackageImpl.java2
2 files changed, 4 insertions, 2 deletions
diff --git a/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/impl/RepresentationPackageImpl.java b/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/impl/RepresentationPackageImpl.java
index 0eb6e133c31..db690c83a25 100644
--- a/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/impl/RepresentationPackageImpl.java
+++ b/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/impl/RepresentationPackageImpl.java
@@ -30,6 +30,7 @@ import org.eclipse.papyrus.infra.architecture.representation.Rule;
import org.eclipse.papyrus.infra.constraints.ConstraintsPackage;
import org.eclipse.papyrus.infra.core.architecture.ArchitecturePackage;
+import org.eclipse.papyrus.infra.types.ElementTypesConfigurationsPackage;
/**
* <!-- begin-user-doc -->
@@ -129,6 +130,7 @@ public class RepresentationPackageImpl extends EPackageImpl implements Represent
// Initialize simple dependencies
ArchitecturePackage.eINSTANCE.eClass();
ConstraintsPackage.eINSTANCE.eClass();
+ ElementTypesConfigurationsPackage.eINSTANCE.eClass();
// Create package meta-data objects
theRepresentationPackage.createPackageContents();

Back to the top
diff --git a/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/RepresentationPackage.java b/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/RepresentationPackage.java
index 954820eeb2b..4186010e7ad 100644
--- a/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/RepresentationPackage.java
+++ b/plugins/infra/architecture/org.eclipse.papyrus.infra.architecture.representation/src-gen/org/eclipse/papyrus/infra/architecture/representation/RepresentationPackage.java
@@ -89,13 +89,13 @@ public interface RepresentationPackage extends EPackage {
int PAPYRUS_REPRESENTATION_KIND__NAME = ArchitecturePackage.REPRESENTATION_KIND__NAME;
/**
* The feature id for the '<em><b>Desciption</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int PAPYRUS_REPRESENTATION_KIND__DESCIPTION = ArchitecturePackage.REPRESENTATION_KIND__DESCIPTION;
+ int PAPYRUS_REPRESENTATION_KIND__DESCRIPTION = ArchitecturePackage.REPRESENTATION_KIND__DESCRIPTION;
/**
* The feature id for the '<em><b>Qualified Name</b></em>' attribute.
@@ -89,13 +89,13 @@ public interface RepresentationPackage extends EPackage {
int PAPYRUS_REPRESENTATION_KIND__NAME = ArchitecturePackage.REPRESENTATION_KIND__NAME;
/**
- * The feature id for the '<em><b>Desciption</b></em>' attribute.
+ * The feature id for the '<em><b>Description</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->